/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy 
 * http://www.e-taxonomy.eu
 * 
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.actions.cdm;

/**
 * @author p.ciardelli
 * @created 14.05.2008
 * @version 1.0
 */
import org.apache.log4j.Logger;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.commands.operations.IOperationHistory;
import org.eclipse.core.commands.operations.IUndoContext;
import org.eclipse.core.commands.operations.IUndoableOperation;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.resource.ImageDescriptor;

import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.taxeditor.ITaxEditorConstants;
import eu.etaxonomy.taxeditor.TaxEditorPlugin;
import eu.etaxonomy.taxeditor.controller.GlobalController;
import eu.etaxonomy.taxeditor.operations.DeleteTaxonOperation;

/**
 * Delete this taxon from the CDM
 * 
 * @author p.ciardelli
 * 
 */
public class DeleteTaxonAction extends Action {
	private static final Logger logger = Logger
			.getLogger(DeleteTaxonAction.class);

	private static String text = "Delete taxon from tree";
	private ImageDescriptor image = TaxEditorPlugin.getDefault()
			.getImageDescriptor(ITaxEditorConstants.ACTIVE_DELETE_ICON);

	private IUndoContext undoContext;
	
	Taxon taxon;

	public DeleteTaxonAction() {
		super(text);
		setImageDescriptor(image);
		
		undoContext = GlobalController.getWorkbenchUndoContext();
	}

	public DeleteTaxonAction(Taxon taxon) {
		this();

		this.taxon = taxon;
	}

	public void run() {
		IUndoableOperation operation = new DeleteTaxonOperation
				(this.getText(), undoContext, taxon);

		GlobalController.executeOperation(operation);
	}
}