/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy 
 * http://www.e-taxonomy.eu
 * 
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.actions.ui;

import java.util.List;

import org.apache.log4j.Logger;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.jface.wizard.Wizard;
import org.eclipse.jface.wizard.WizardDialog;

import eu.etaxonomy.cdm.model.name.NameRelationship;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.taxeditor.controller.GlobalController;
import eu.etaxonomy.taxeditor.propertysheet.namerelationswizard.NameRelationWizard;
import eu.etaxonomy.taxeditor.propertysheet.namerelationswizard.NameRelationWizardModel;

/**
 * @author p.ciardelli
 * @created 04.06.2008
 * @version 1.0
 */
public class OpenNameRelationWizardAction extends Action {
	private static final Logger logger = Logger
			.getLogger(OpenNameRelationWizardAction.class);

	private static String text = "Create name relation ...";
//	private ImageDescriptor image = TaxEditorPlugin.getDefault()
//			.getImageDescriptor(ITaxEditorConstants.ACTIVE_DELETE_ICON);
	private ImageDescriptor image = null;
	public static final String ID = "eu.etaxonomy.taxeditor.actions.opennamerelationswizard"; //$NON-NLS-1$

	private NameRelationWizardModel relationModel;

	private OpenNameRelationWizardAction() {
		super(text);
		setImageDescriptor(image);
		setId(ID);
	}

	public OpenNameRelationWizardAction(TaxonNameBase name) {
		this();
		
		this.relationModel = new NameRelationWizardModel(name);
	}

	public OpenNameRelationWizardAction(TaxonNameBase name,
			List<NameRelationship> nameRelationsList) {
		this(name);
		
		this.relationModel.setNameRelationsList(nameRelationsList); 
	}

	public OpenNameRelationWizardAction(TaxonNameBase name,
			NameRelationship relation) {
		this(name);
		
		this.relationModel.setRelation(relation);
	}

	public void run() {
		if (relationModel.getBaseName() == null) {
			return;
		}
		
		Wizard wizard = new NameRelationWizard(relationModel);
		
		WizardDialog dialog = new WizardDialog(GlobalController.getShell(), wizard);
		dialog.create();
		dialog.open();
	}
}