/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.actions.ui;

import org.apache.log4j.Logger;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.resource.ImageDescriptor;

import eu.etaxonomy.cdm.model.name.NonViralName;
import eu.etaxonomy.cdm.model.reference.ReferenceBase;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.taxeditor.ITaxEditorConstants;
import eu.etaxonomy.taxeditor.TaxEditorPlugin;
import eu.etaxonomy.taxeditor.controller.EditorController;
import eu.etaxonomy.taxeditor.preference.PreferencesUtil;

/**
 * Opens a name editor for a new taxon with a parent taxon
 * 
 * @author p.ciardelli
 * @created 02.06.2008
 * @version 1.0
 */
public class OpenNewChildNameEditorAction extends Action {
	private static final Logger logger = Logger
			.getLogger(OpenNewChildNameEditorAction.class);

	private static String text = "Add child taxon";
	private ImageDescriptor image = TaxEditorPlugin.getDefault()
			.getImageDescriptor(ITaxEditorConstants.ADD_CHILD_TAXON_ICON);

	private Taxon taxon;
	private Taxon parentTaxon;
	public static final String ID = "eu.etaxonomy.taxeditor.actions.opennameeditoraction"; //$NON-NLS-1$
	
	private OpenNewChildNameEditorAction() {
		super(text);
		setImageDescriptor(image);
		setId(ID);
	}
	
	public OpenNewChildNameEditorAction(Taxon parentTaxon) {
		this();
		
		this.parentTaxon = parentTaxon;
	}
	
	public void run() {
		
		NonViralName name = PreferencesUtil.getInstanceOfPreferredNameClass();
		ReferenceBase sec = parentTaxon.getSec();
		taxon = Taxon.NewInstance(name, sec);
		
		parentTaxon.addTaxonomicChild(taxon, null, null);
		
		// Open editor for new taxon
		EditorController.open(taxon);
		
		
		//new OpenTaxonEditorAction(taxon).run();
	}
}