/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.editor.name;

import org.apache.log4j.Logger;
import org.eclipse.jface.action.MenuManager;
import org.eclipse.swt.graphics.Font;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.forms.IManagedForm;
import org.eclipse.ui.views.properties.IPropertySource;

import eu.etaxonomy.cdm.model.common.OrderedTermVocabulary;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.cdm.model.taxon.TaxonRelationshipType;
import eu.etaxonomy.taxeditor.TaxEditorPlugin;
import eu.etaxonomy.taxeditor.actions.name.CreateConceptRelationAction;
import eu.etaxonomy.taxeditor.actions.name.CreateMisappliedNameAction;
import eu.etaxonomy.taxeditor.actions.ui.ChangeTaxonToSynonymAction;
import eu.etaxonomy.taxeditor.actions.ui.MoveTaxonDialogAction;
import eu.etaxonomy.taxeditor.editor.ContextMenu;
import eu.etaxonomy.taxeditor.model.CdmSessionDataRepository;
import eu.etaxonomy.taxeditor.propertysheet.name.TaxonBasePropertySource;

/**
 * @author p.ciardelli
 * @created 13.01.2009
 * @version 1.0
 */
public class AcceptedNameComposite extends NameComposite {
	@SuppressWarnings("unused")
	private static final Logger logger = Logger
			.getLogger(AcceptedNameComposite.class);
	
	public AcceptedNameComposite(Composite groupComposite, IManagedForm form,
			Taxon taxon) {
		super(groupComposite, form, NameComposite.ACCEPTED_TAXON, taxon);
	
		setDraggable(false);
		setIcon(ACCEPTED_ICON);
		setFont(getViewerFont());
		setIndent(ACCEPTED_INDENT);

		createMenu();
		
		initNameViewer(taxon);
	}

	private void createMenu() {
		ContextMenu contextMenu = createContextMenu();

		contextMenu.addAction(new ChangeTaxonToSynonymAction(getTaxon()));
		contextMenu.addAction(new MoveTaxonDialogAction(getTaxon()));
		contextMenu.addSeparator();
		contextMenu.addAction(new CreateMisappliedNameAction(getTaxon()));
		
		MenuManager subMenu = new MenuManager("Create concept relation");
		for (TaxonRelationshipType type : 
				CdmSessionDataRepository.getDefault().getTaxonRelationshipTypes()) {
			subMenu.add(new CreateConceptRelationAction(
					getTaxon(), type));
		}
		contextMenu.addSubmenu(subMenu);
		
		
		// TODO Make action "Create autonym and subspecies"
//		contextMenu.addSeparator();
//		
//		contextMenu.addAction(new CreateAutonym(getTaxon()));
//		contextMenu.addAction(new CreateSubspecies(getTaxon()));
	}

	@Override
	public IPropertySource getPropertySource() {
		return new TaxonBasePropertySource(taxon, "Accepted Name");
	}
	
	@Override
	protected Font getViewerFont() {
		return ACCEPTED_FONT;
	}

	@Override
	protected TaxonNameBase getName() {
		return taxon.getName();
	}
}