/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.operations.name;

import org.apache.log4j.Logger;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.commands.operations.IUndoContext;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;

import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.taxon.SynonymRelationshipType;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.cdm.model.taxon.TaxonRelationshipType;
import eu.etaxonomy.taxeditor.editor.name.CdmParserController;
import eu.etaxonomy.taxeditor.operations.AbstractEditorOperation;

/**
 * @author p.ciardelli
 * @created 21.01.2009
 * @version 1.0
 */
public class CreateMisappliedNameOperation extends AbstractEditorOperation {
	private static final Logger logger = Logger
			.getLogger(CreateMisappliedNameOperation.class);
	
	private Taxon misapplication;

	public CreateMisappliedNameOperation(String label, IUndoContext undoContext,
			Taxon taxon) {
		super(label, undoContext, taxon);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#execute(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus execute(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		
		// Create empty new name
		TaxonNameBase misapplicationName = 
				CdmParserController.parseFullReference("", null, null);
		
		// make misapplication name with misapplication name
		misapplication = Taxon.NewInstance(misapplicationName, null);
						
		// add misapplied name to taxon
		// TODO add microcitation for misapplied name to property sheet
		taxon.addMisappliedName(misapplication, null, null);	
		
		// redraw editor if exists
		return redrawOpenEditor();
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#redo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus redo(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		return execute(monitor, info);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#undo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus undo(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		
		// Remove misapplied name from taxon
		taxon.removeTaxon(misapplication, TaxonRelationshipType.MISAPPLIED_NAME_FOR());
					
		// Redraw editor if exists
		return redrawOpenEditor();
	}
}