/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.propertysheet;

import org.apache.log4j.Logger;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.ui.views.properties.IPropertySource;

import eu.etaxonomy.cdm.model.description.DescriptionElementBase;
import eu.etaxonomy.cdm.model.description.TaxonDescription;
import eu.etaxonomy.cdm.model.name.BotanicalName;
import eu.etaxonomy.cdm.model.name.NonViralName;
import eu.etaxonomy.cdm.model.name.ZoologicalName;
import eu.etaxonomy.cdm.model.taxon.TaxonBase;
import eu.etaxonomy.taxeditor.propertysheet.description.DescriptionElementPropertySource;
import eu.etaxonomy.taxeditor.propertysheet.description.TaxonDescriptionPropertySource;
import eu.etaxonomy.taxeditor.propertysheet.name.BotanicalNamePropertySource;
import eu.etaxonomy.taxeditor.propertysheet.name.NonViralNamePropertySource;
import eu.etaxonomy.taxeditor.propertysheet.name.TaxonBasePropertySource;
import eu.etaxonomy.taxeditor.propertysheet.name.ZoologicalNamePropertySource;

/**
 * Returns a property source appropriate to the selected object. 
 * 
 * @author p.ciardelli
 * @created 21.05.2008
 * @version 1.0
 */
public class PropertySourceAdapter {
	private static final Logger logger = Logger
			.getLogger(PropertySourceAdapter.class);
	
	private Object propertyObject;

	public PropertySourceAdapter(Object propertyObject) {
		this.propertyObject = propertyObject;
	}

	public IPropertySource getPropertySource() {
		Class clazz = propertyObject.getClass();
		
		// Property source for Description-related classes
		if (clazz == TaxonDescription.class) {
			return new TaxonDescriptionPropertySource((TaxonDescription) propertyObject);
		}
		
		if (propertyObject instanceof DescriptionElementBase) {
			return new DescriptionElementPropertySource((DescriptionElementBase) propertyObject);
		}		
		
		// Property source for misapplied name
//		if (propertyObject instanceof TaxonBase) {
//			return new TaxonBasePropertySource((TaxonBase) propertyObject);
//		}
//		
		// Property sources for names
		if (clazz == BotanicalName.class) {
			return new BotanicalNamePropertySource((BotanicalName) propertyObject);
		}
		if (clazz == ZoologicalName.class) {
			return new ZoologicalNamePropertySource((ZoologicalName) propertyObject);
		}
		if (clazz == NonViralName.class) {
			return new NonViralNamePropertySource((NonViralName) propertyObject);
		}
		
		return null;
	}
}
